| register_serial | R Documentation |
Registers a serialization configuration, which may be set to perform custom
serialization and unserialization of normally non-exportable reference
objects, allowing these to be used seamlessly between different R sessions.
Once registered, the functions apply to all daemons() calls where the
serial argument is NULL.
register_serial(class, sfunc, ufunc)
class |
(character) class name(s) for custom serialization, e.g.
|
sfunc |
(function | list) serialization function(s) accepting a reference object and returning a raw vector. |
ufunc |
(function | list) unserialization function(s) accepting a raw vector and returning a reference object. |
Invisible NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.