| require_daemons | R Documentation |
Returns TRUE invisibly only if daemons are set, otherwise produces an
informative error for the user to set daemons, with a clickable function link
if the cli package is available.
require_daemons(.compute = NULL, call = environment())
.compute |
(character) name of the compute profile. Each profile has its
own independent set of daemons. |
call |
(environment) execution environment for error attribution, e.g.
|
Invisibly, logical TRUE, or else errors.
daemons(sync = TRUE)
(require_daemons())
daemons(0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.