dispatcher: Dispatcher

View source: R/dispatcher.R

dispatcherR Documentation

Dispatcher

Description

Dispatches tasks from a host to daemons for processing, using FIFO scheduling, queuing tasks as required. Daemon / dispatcher settings are controlled by daemons() and this function should not need to be called directly.

Usage

dispatcher(host, url = NULL, n = 0L)

Arguments

host

(character) URL to dial into, typically an IPC address.

url

(character) URL to listen at for daemon connections, e.g. 'tcp://hostname:5555'. Use 'tls+tcp://' for secure TLS.

n

(integer) number of local daemons launched by host.

Details

Dispatcher acts as a gateway between the host and daemons, dispatching tasks on a FIFO basis. Tasks are queued until a daemon is available for immediate execution.

Value

Invisibly, an integer exit code: 0L for normal termination.


mirai documentation built on Feb. 13, 2026, 9:07 a.m.