| nextstream | R Documentation |
nextstream retrieves the currently stored L'Ecuyer-CMRG RNG stream
for the specified compute profile and advances it to the next stream.
nextget retrieves the specified item from the specified compute profile.
nextcode translates integer exit codes returned by daemon().
nextstream(.compute = "default")
nextget(x, .compute = "default")
nextcode(xc)
.compute |
(character) name of the compute profile. Each profile has its
own independent set of daemons. |
x |
(character) item to retrieve: |
xc |
(integer) return value from |
These functions are exported for use by packages extending mirai with
alternative launchers of daemon() processes.
For nextstream: Calling this function advances the stream stored within
the compute profile. This ensures that the next recursive stream is returned
on subsequent calls.
For nextstream: a length 7 integer vector, as given by
.Random.seed when the L'Ecuyer-CMRG RNG is in use (may be passed directly
to the rs argument of daemon()), or else NULL if a stream has not yet
been created.
For nextget: the requested item, or else NULL if not present.
For nextcode: character string.
daemons(sync = TRUE)
nextstream()
nextstream()
nextget("url")
daemons(0)
nextcode(0L)
nextcode(1L)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.