| remote_config | R Documentation |
Provides a flexible generic framework for generating the shell commands to deploy daemons remotely.
remote_config(
command = NULL,
args = c("", "."),
rscript = "Rscript",
quote = FALSE
)
command |
(character) shell command for launching daemons (e.g.
|
args |
(character vector) arguments to |
rscript |
(character) Rscript executable. Use full path if needed, or
|
quote |
(logical) whether to quote the daemon launch command. Required
for |
A list in the required format to be supplied to the remote argument
of daemons() or launch_remote().
ssh_config(), cluster_config() and http_config() for other
types of remote configuration.
# Slurm srun example
remote_config(
command = "srun",
args = c("--mem 512", "-n 1", "."),
rscript = file.path(R.home("bin"), "Rscript")
)
# SSH requires 'quote = TRUE'
remote_config(
command = "/usr/bin/ssh",
args = c("-fTp 22 10.75.32.90", "."),
quote = TRUE
)
# can be used to start local daemons with special configurations
remote_config(
command = "Rscript",
rscript = "--default-packages=NULL --vanilla"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.