Retrieve status information for the specified compute profile, comprising current connections, daemons status, and (when using dispatcher) queue depth and memory pressure.
Value
A named list comprising:
connections - integer number of active daemon connections.
daemons - character URL at which host / dispatcher is listening, or else
0Lif daemons have not yet been set.mirai (present only if using dispatcher) - a named integer vector comprising: awaiting - number of tasks queued for execution at dispatcher, executing - number of tasks sent to a daemon for execution, and completed - number of tasks for which the result has been received (either completed or cancelled).
memory (present only if using dispatcher) - a named numeric vector in MB (metric, 1 MB = 1,000,000 bytes) comprising: used - current and peak - high-watermark queued task payloads at dispatcher, and capacity - the value set as the
memoryargument todaemons()(NA_real_if unset/unbounded).
See also
info() for more succinct information statistics.