| status | R Documentation |
Retrieve status information for the specified compute profile, comprising current connections and daemons status.
status(.compute = NULL)
.compute |
(character | miraiCluster) compute profile name, or |
A named list comprising:
connections - integer number of active daemon connections.
daemons - character URL at which host / dispatcher is
listening, or else 0L if daemons have not yet been set.
mirai (present only if using dispatcher) - a named integer vector comprising: awaiting - number of tasks queued for execution at dispatcher, executing - number of tasks sent to a daemon for execution, and completed - number of tasks for which the result has been received (either completed or cancelled).
info() for more succinct information statistics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.