unresolved: Query if a mirai is Unresolved

unresolvedR Documentation

Query if a mirai is Unresolved

Description

Query whether a 'mirai', 'mirai' value or list of 'mirai' remains unresolved. Unlike call_mirai(), this function does not wait for completion.

Usage

unresolved(x)

Arguments

x

(mirai | list | mirai value) a 'mirai', list of 'mirai' objects, or value from ⁠$data⁠.

Details

Suitable for use in control flow statements such as while or if.

Value

Logical TRUE if x is an unresolved 'mirai' or 'mirai' value or the list contains at least one unresolved 'mirai', or FALSE otherwise.

Examples


m <- mirai(Sys.sleep(0.1))
unresolved(m)
Sys.sleep(0.3)
unresolved(m)


mirai documentation built on Feb. 13, 2026, 9:07 a.m.